@@ -160,8 +160,8 @@ class DicomWriter:
 
         # Store value of MediaStorageSOPInstanceUID.
         # This will be the root UID when saving data for image slices.
-        self.mediaStorageSOPInstanceUID = (
-                self.ds.file_meta.MediaStorageSOPInstanceUID)
+        self.mediaStorageSOPInstanceUID = getattr(
+                self.ds.file_meta, "MediaStorageSOPInstanceUID", None)
 
     def add_to_image_dataset(self, ds):
         '''
@@ -222,10 +222,10 @@ class DicomWriter:
         file_meta = FileMetaDataset()
         file_meta.FileMetaInformationVersion = b'\x00\x01'
         file_meta.MediaStorageSOPClassUID = media_storage_sop_class_uid
-        file_meta.MediaStorageSOPInstanceUID = generate_uid(self.root_uid)
+        file_meta.MediaStorageSOPInstanceUID = self.generate_shortened_uid()
         file_meta.TransferSyntaxUID = transfer_syntax_uid
         version = pydicom.__version__
-        file_meta.ImplementationClassUID = f'{self.root_uid}.{version}'
+        file_meta.ImplementationClassUID = f'{self.root_uid}{version}'
         file_meta.ImplementationVersionName = f'pydicom-{version}'
 
         # Create FileDataset instance
@@ -254,7 +254,7 @@ class DicomWriter:
         ds.ReferringPhysicianName = None
         ds.SeriesDate = self.date
         ds.SeriesDescription = None
-        ds.SeriesInstanceUID = generate_uid(self.root_uid)
+        ds.SeriesInstanceUID = self.generate_shortened_uid()
         ds.SeriesNumber = None
         ds.SeriesTime = self.time
         ds.SoftwareVersions = f'pydicom-{version}'
@@ -263,7 +263,7 @@ class DicomWriter:
         ds.StationName = None
         ds.StudyDate = self.date
         ds.StudyDescription = None
-        ds.StudyInstanceUID = generate_uid(self.root_uid)
+        ds.StudyInstanceUID = self.generate_shortened_uid()
         ds.StudyTime = self.time
         ds.StudyID = None
 
@@ -274,6 +274,25 @@ class DicomWriter:
 
         return ds
 
+    def generate_shortened_uid(self, max_length=55):
+        '''
+        Return shortened UID.
+
+        UIDs generated by pydicom.uid.generate_uid() are up to 64 characters.
+        Some UIDs need to have additional characters appended, for example
+        to identify image slices.  This can result in UIDs that are longer
+        than is allowed by the DICOM standard.  To avoid this, the initial
+        UIDs may be shortened.
+
+        **Parameter:**
+        
+        max_length : int, default=-10
+            Length to which UID should be shortened.  If the UID initially
+            generated is shorter than this, then it's returned unchanged.
+        '''
+        uid = generate_uid(self.root_uid)
+        return uid[: min(len(uid), max_length)]
+
     def get_file_dataset(self):
         '''
         Attempt to retrieve pydicom.dataset.FileDataset from source.
@@ -504,7 +523,7 @@ class DicomWriter:
 
             roi_contour = Dataset()
 #            roi_contour.ROIDisplayColor = list(map(str, roi.color))
-            roi_contour.ROIDisplayColor = [f'{255 * rgb}'
+            roi_contour.ROIDisplayColor = [f'{255 * rgb : .0f}'
                     for rgb in roi.color[0 : 3]]
             roi_contour.ReferencedROINumber = number
             roi_contour.ContourSequence = Sequence()
